# ImageURL


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**url** | **str** | URL of the image | 

## Example

```python
from _generated.models.image_url import ImageURL

# TODO update the JSON string below
json = "{}"
# create an instance of ImageURL from a JSON string
image_url_instance = ImageURL.from_json(json)
# print the JSON string representation of the object
print(ImageURL.to_json())

# convert the object into a dict
image_url_dict = image_url_instance.to_dict()
# create an instance of ImageURL from a dict
image_url_from_dict = ImageURL.from_dict(image_url_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


